#ifndef MISC_H
#define MISC_H
#define uchar unsigned char
char* view_chararr2hexstrbe(int, uchar*);
char* view_chararr2hexstr(int, uchar*);
char* view_chararr2asciistr(int, uchar*);
uchar* view_chararrAddint(int, uchar*, int);
void view_chararrAddintsame(int, uchar*,int);
uchar* view_chararrAddchararr(int, uchar*,uchar*);
int view_chararrSubchararr(int, uchar*, uchar*);
long view_chararrSublong (int count, uchar* value1, long value2);
int view_chararr2int(int, uchar*);
long view_chararr2long(int, uchar*);
uchar* view_int2chararr(int,int);
void view_chararrCpychararr(int, uchar* , uchar*);
int view_hexstr2chararr2(int, char*, uchar*);
int view_hexstr2chararr(int, char*, uchar*);
int view_findstrinarr(char*, GList**,int);
char* view_chararrinregbank(int,uchar*);
void g_list_free_contents (GList* list);

#endif
